@@ -1,7 +1,9 @@
 # Copyright (c) 2007, 2009-2010, 2013 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
 # Copyright (c) 2014 Google, Inc.
-# Copyright (c) 2015-2016 Cara Vinson <ceridwenv@gmail.com>
-# Copyright (c) 2015-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015-2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015-2016 Ceridwen <ceridwenv@gmail.com>
+# Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
+# Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
@@ -24,7 +26,8 @@ class AstroidError(Exception):
     will be called with the field names and values supplied as keyword
     arguments.
     """
-    def __init__(self, message='', **kws):
+
+    def __init__(self, message="", **kws):
         super(AstroidError, self).__init__(message)
         self.message = message
         for key, value in kws.items():
@@ -42,7 +45,7 @@ class AstroidBuildingError(AstroidError):
         error: Exception raised during construction.
     """
 
-    def __init__(self, message='Failed to import module {modname}.', **kws):
+    def __init__(self, message="Failed to import module {modname}.", **kws):
         super(AstroidBuildingError, self).__init__(message, **kws)
 
 
@@ -57,11 +60,15 @@ class TooManyLevelsError(AstroidImportError):
         level: The level which was attempted.
         name: the name of the module on which the relative import was attempted.
     """
+
     level = None
     name = None
 
-    def __init__(self, message='Relative import with too many levels '
-                               '({level}) for module {name!r}', **kws):
+    def __init__(
+        self,
+        message="Relative import with too many levels " "({level}) for module {name!r}",
+        **kws
+    ):
         super(TooManyLevelsError, self).__init__(message, **kws)
 
 
@@ -77,10 +84,11 @@ class NoDefault(AstroidError):
         func: Function node.
         name: Name of argument without a default.
     """
+
     func = None
     name = None
 
-    def __init__(self, message='{func!r} has no default for {name!r}.', **kws):
+    def __init__(self, message="{func!r} has no default for {name!r}.", **kws):
         super(NoDefault, self).__init__(message, **kws)
 
 
@@ -92,6 +100,7 @@ class ResolveError(AstroidError):
     Standard attributes:
         context: InferenceContext object.
     """
+
     context = None
 
 
@@ -103,12 +112,14 @@ class MroError(ResolveError):
         cls: ClassDef node whose MRO resolution failed.
         context: InferenceContext object.
     """
+
     mros = ()
     cls = None
 
     def __str__(self):
-        mro_names = ", ".join("({})".format(", ".join(b.name for b in m))
-                              for m in self.mros)
+        mro_names = ", ".join(
+            "({})".format(", ".join(b.name for b in m)) for m in self.mros
+        )
         return self.message.format(mros=mro_names, cls=self.cls)
 
 
@@ -121,13 +132,13 @@ class InconsistentMroError(MroError):
 
 
 class SuperError(ResolveError):
-
-    """Error raised when there is a problem with a super call.
+    """Error raised when there is a problem with a *super* call.
 
     Standard attributes:
-        super_: The Super instance that raised the exception.
+        *super_*: The Super instance that raised the exception.
         context: InferenceContext object.
     """
+
     super_ = None
 
     def __str__(self):
@@ -141,10 +152,11 @@ class InferenceError(ResolveError):
         node: The node inference was called on.
         context: InferenceContext object.
     """
+
     node = None
     context = None
 
-    def __init__(self, message='Inference failed for {node!r}.', **kws):
+    def __init__(self, message="Inference failed for {node!r}.", **kws):
         super(InferenceError, self).__init__(message, **kws)
 
 
@@ -158,10 +170,11 @@ class NameInferenceError(InferenceError):
         scope: The node representing the scope in which the lookup occurred.
         context: InferenceContext object.
     """
+
     name = None
     scope = None
 
-    def __init__(self, message='{name!r} not found in {scope!r}.', **kws):
+    def __init__(self, message="{name!r} not found in {scope!r}.", **kws):
         super(NameInferenceError, self).__init__(message, **kws)
 
 
@@ -173,10 +186,11 @@ class AttributeInferenceError(ResolveError):
         attribute: The attribute for which lookup failed, as a string.
         context: InferenceContext object.
     """
+
     target = None
     attribute = None
 
-    def __init__(self, message='{attribute!r} not found on {target!r}.', **kws):
+    def __init__(self, message="{attribute!r} not found on {target!r}.", **kws):
         super(AttributeInferenceError, self).__init__(message, **kws)
 
 
